@@ -62,6 +62,20 @@ struct WebsocketMsg<T: Sized> {
     data: Vec<T>,
 }
 
+pub(crate) fn extract_symbol(_market_type: MarketType, msg: &str) -> Option<String> {
+    let ws_msg = serde_json::from_str::<WebsocketMsg<Value>>(msg).unwrap();
+    let symbols = ws_msg
+        .data
+        .iter()
+        .map(|v| v["symbol"].as_str().unwrap())
+        .collect::<Vec<&str>>();
+    if symbols.is_empty() {
+        None
+    } else {
+        Some(symbols[0].to_string())
+    }
+}
+
 pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<TradeMsg>> {
     let ws_msg = serde_json::from_str::<WebsocketMsg<RawTradeMsg>>(msg)?;
     let raw_trades = ws_msg.data;
